Orchestra (Orchestra v1.1.0)
Retrieve modules implementing specific behaviours.
Summary
Functions
Provide a list of applications to search for modules implementing a specific behaviour.
Retrieve modules implementing a specific behaviour from the provided applications.
Retrieve a list of maps with the module and its source path.